# Satel Integra: Asynchronous python client for Satel Integra

![PyPI - Version](https://img.shields.io/pypi/v/satel-integra)
![Pypi - Python Versions](https://img.shields.io/pypi/pyversions/satel-integra)
[![Licence](https://img.shields.io/github/license/c-soft/satel_integra)](LICENSE)

[![Build Status](https://github.com/c-soft/satel_integra/actions/workflows/ci.yml/badge.svg)](https://github.com/c-soft/satel_integra/actions/workflows/ci.yml)
[![Open in Dev Containers](https://img.shields.io/static/v1?label=Dev%20Containers&message=Open&color=blue&logo=visualstudiocode)](https://vscode.dev/redirect?url=vscode://ms-vscode-remote.remote-containers/cloneInVolume?url=https://github.com/c-soft/satel_integra)

## About

Communication library and basic testing tool for Satel Integra alarm system. Communication via TCP/IP protocol published by SATEL.

## Installation

```bash
pip install satel_integra
```

## Usage

To use Satel Integra in a project, follow the example, replace values where needed:

```python
from satel_integra import AsyncSatel
```

For complete examples, look into the [examples](examples/) folder.

## Contributing

Contributions are welcome! If you want to contribute, have a look at [the contribution file](CONTRIBUTING.md).

## License

Refer to the [licence file](LICENCE).

## Features

-   TODO

## Credits

Original creator of the library is [Krzysztof Machelski](https://github.com/c-soft)

All contributors are listed on [the contributor's page](https://github.com/c-soft/satel_integra/graphs/contributors)
